
package org.ow2.petals.engine.helloworld.listener;

import javax.jbi.messaging.MessagingException;

import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.component.framework.listener.AbstractJBIListener;
import org.ow2.petals.engine.helloworld.HelloWorldEngine;
import org.ow2.petals.engine.helloworld.Helloworld;

/**
 * JBI listener for helloworld component
 *
 * @author Olivier FABRE (ofabre) - eBM WebSourcing
 *
 */
public class JBIListener extends AbstractJBIListener {

    private static final String PRINT_MESS = "printMessage";

    private static final String SAY_HELLO = "sayHello";

    private Helloworld helloworld;

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.common.listener.AbstractListener#init()
     */
    @Override
    protected void init() {
        this.helloworld = ((HelloWorldEngine) getComponent()).getHelloworld();
    }

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.common.listener.AbstractJBIListener#onJBIMessage(org.objectweb.petals.component.common.util.MessageExchangeWrapper)
     */
    public void onJBIMessage(Exchange exchange) {
        String outContent = null;
        boolean outResponse = false;
        try {
            // Get Operation name
            String opName = exchange.getOperationName();

            // Get in Message content
            String stringContent = exchange.getInMessageContentAsString();

            if (PRINT_MESS.equalsIgnoreCase(opName)) {
                if (exchange.isInOnlyPattern()
                        || exchange.isRobustInOnlyPattern()) {
                    helloworld.printMessage(stringContent);
                } else {
                    throw new MessagingException("Uncompatible MEP '"
                            + exchange.getPattern().toString()
                            + "' and operation '" + opName + "'");
                }
            } else if (SAY_HELLO.equalsIgnoreCase(opName)) {
                if (exchange.isInOutPattern()
                        || exchange.isInOptionalOutPattern()) {
                    outContent = helloworld.sayHello(stringContent);
                } else {
                    throw new MessagingException("Uncompatible MEP '"
                            + exchange.getPattern().toString()
                            + "' and operation '" + opName + "'");
                }
                outResponse = true;
            } else {
                throw new MessagingException("Unknown operation '" + opName
                        + "'");
            }

            if (outResponse) {
                exchange.setOutMessageContent(outContent);
            }
        } catch (MessagingException e) {
            exchange.setError(e);
        }
    }
}
